@@ -69,12 +69,12 @@ xload_screen(int rep, int display, int *flags_ptr)
 
 		sock_send_string(sock, "screen_add L\n");
 		sock_printf(sock, "screen_set L -name {Load: %s}\n", get_hostname());
-		// Add the vbars...
+		/* Add the vbars... */
 		for (i = 1; i < lcd_wid; i++) {
 			sock_printf(sock, "widget_add L bar%i vbar\n", i);
 			sock_printf(sock, "widget_set L bar%i %i %i 0\n", i, i, lcd_hgt);
 		}
-		// And add a title...
+		/* And add a title... */
 		if (lcd_hgt > 2) {
 			sock_send_string(sock, "widget_add L title title\n");
 			sock_send_string(sock, "widget_set L title {LOAD        }\n");
@@ -89,19 +89,21 @@ xload_screen(int rep, int display, int *flags_ptr)
 		sock_printf(sock, "widget_set L top %i %i 1\n", lcd_wid, (lcd_hgt + 1 - gauge_hgt));
 	}
 
-	// shift load history
+	/* shift load history */
 	for (i = 0; i < (lcd_wid - 2); i++)
 		loads[i] = loads[i + 1];
 
-	// get new load value
-	// ignore failure: the shift above makes sure we still have the prev. value
+	/*
+	 * get new load value, ignore failure: the shift above makes sure we
+	 * still have the previous value
+	 */
 	machine_get_loadavg(&(loads[lcd_wid - 2]));
 
-	// determine max. load from history
+	/* determine max. load from history */
 	for (i = 0; i < lcd_wid - 1; i++)
 		loadmax = max(loadmax, loads[i]);
 
-	// poor man's ceil()
+	/* poor man's ceil() */
 	loadtop = (int) loadmax;
 	if (loadtop < loadmax)
 		loadtop++;
@@ -109,7 +111,7 @@ xload_screen(int rep, int display, int *flags_ptr)
 
 	factor = (double) (lcd_cellhgt * gauge_hgt) / (double) loadtop;
 
-	// display load
+	/* display load */
 	sock_printf(sock, "widget_set L top %i %i %i\n", lcd_wid, (lcd_hgt + 1 - gauge_hgt), loadtop);
 
 	for (i = 0; i < lcd_wid - 1; i++) {
@@ -118,13 +120,13 @@ xload_screen(int rep, int display, int *flags_ptr)
 		sock_printf(sock, "widget_set L bar%i %i %i %i\n", i + 1, i + 1, lcd_hgt, (int) x);
 	}
 
-	// And now the title...
+	/* And now the title... */
 	if (lcd_hgt > 2)
 		sock_printf(sock, "widget_set L title {LOAD %2.2f: %s}\n", loads[lcd_wid - 2], get_hostname());
 	else
 		sock_printf(sock, "widget_set L title 1 1 {%s %2.2f}\n", get_hostname(), loads[lcd_wid - 2]);
 
-	// set return status depending on max & current load
+	/* set return status depending on max & current load */
 	if (lowLoad < highLoad) {
 		status = (loadmax > lowLoad) ? BACKLIGHT_ON : BACKLIGHT_OFF;
 		if (loads[lcd_wid - 2] > highLoad)
@@ -132,4 +134,4 @@ xload_screen(int rep, int display, int *flags_ptr)
 	}
 
 	return status;
-}	// End xload_screen()
+}
