@@ -64,8 +64,8 @@ mem_screen(int rep, int display, int *flags_ptr)
 
 		if (lcd_hgt >= 4) {
 			gauge_wid = (lcd_wid >= 18)
-				    ? (lcd_wid - 6) / 2		// room for E..F pairs and 2 spaces in between
-				    : (lcd_wid - 4) / 2;	// leave room for the  E...F pairs
+				    ? (lcd_wid - 6) / 2		/* room for E..F pairs and 2 spaces in between */
+				    : (lcd_wid - 4) / 2;	/* leave room for the  E...F pairs */
 
 			sock_send_string(sock, "widget_add M title title\n");
 			sock_send_string(sock, "widget_set M title { MEM}\n");
@@ -79,10 +79,11 @@ mem_screen(int rep, int display, int *flags_ptr)
 			sock_printf(sock, "widget_set M EFmem 1 4 {E%*sF}\n", gauge_wid, "");
 			sock_send_string(sock, "widget_add M EFswap string\n");
 			sock_printf(sock, "widget_set M EFswap %i 4 {E%*sF}\n",
-					lcd_wid - gauge_wid - 1, gauge_wid, "");
+				    lcd_wid - gauge_wid - 1, gauge_wid, "");
 			sock_send_string(sock, "widget_add M memused string\n");
 			sock_send_string(sock, "widget_add M swapused string\n");
-		} else {
+		}
+		else {
 			gauge_wid = (lcd_wid >= 18) ? max(2, lcd_wid - 18) : 0;
 			gauge_offs = (lcd_wid - gauge_wid) / 2 + 2;
 
@@ -90,9 +91,9 @@ mem_screen(int rep, int display, int *flags_ptr)
 			sock_send_string(sock, "widget_add M s string\n");
 			if (gauge_wid > 0) {
 				sock_printf(sock, "widget_set M m 1 1 {M%*s[%*s]}\n",
-					gauge_offs - 3, "", gauge_wid, "");
+					    gauge_offs - 3, "", gauge_wid, "");
 				sock_printf(sock, "widget_set M s 1 2 {S%*s[%*s]}\n",
-					gauge_offs - 3, "", gauge_wid, "");
+					    gauge_offs - 3, "", gauge_wid, "");
 			}
 			else {
 				sock_send_string(sock, "widget_set M m 1 1 {M   }\n");
@@ -112,82 +113,83 @@ mem_screen(int rep, int display, int *flags_ptr)
 	machine_get_meminfo(mem);
 
 	if (lcd_hgt >= 4) {
-		char tmp[12];	// should be sufficient
+		char tmp[12];	/* should be sufficient */
 
-		// flip the title back and forth... (every 4 updates)
+		/* flip the title back and forth... (every 4 updates) */
 		if (which_title & 4) {
 			sock_printf(sock, "widget_set M subtitle %i 1 {}\n", lcd_wid - 7);
 			sock_printf(sock, "widget_set M title {%s}\n", get_hostname());
-		} else {
+		}
+		else {
 			sock_send_string(sock, "widget_set M title { MEM}\n");
 			sock_printf(sock, "widget_set M subtitle %i 1 { SWAP }\n", lcd_wid - 7);
 		}
 		which_title = (which_title + 1) & 7;
 
-		// Total memory
+		/* Total memory */
 		sprintf_memory(tmp, mem[0].total * 1024.0, 1);
 		if (display)
 			sock_printf(sock, "widget_set M memtotl 1 2 {%7s}\n", tmp);
 
-		// Free memory (plus buffers and cache)
+		/* Free memory (plus buffers and cache) */
 		sprintf_memory(tmp, (mem[0].free + mem[0].buffers + mem[0].cache) * 1024.0, 1);
 		if (display)
 			sock_printf(sock, "widget_set M memused 1 3 {%7s}\n", tmp);
 
-		// Total swap
+		/* Total swap */
 		sprintf_memory(tmp, mem[1].total * 1024.0, 1);
 		if (display)
 			sock_printf(sock, "widget_set M swaptotl %i 2 {%7s}\n", lcd_wid - 7, tmp);
 
-		// Free swap
+		/* Free swap */
 		sprintf_memory(tmp, mem[1].free * 1024.0, 1);
 		if (display)
 			sock_printf(sock, "widget_set M swapused %i 3 {%7s}\n", lcd_wid - 7, tmp);
 
 		if (gauge_wid > 0) {
-			// Free memory graph
+			/* Free memory graph */
 			if (mem[0].total > 0) {
 				double value = 1.0 - (double) (mem[0].free + mem[0].buffers + mem[0].cache)
-	                	                         / (double) mem[0].total;
+					       / (double) mem[0].total;
 
-				//printf(".0f", val) only prints the integer part
+				/* printf(".0f", val) only prints the integer part */
 				if (display)
 					sock_printf(sock, "widget_set M memgauge 2 4 %.0f\n",
-							lcd_cellwid * gauge_wid * value);
+						    lcd_cellwid * gauge_wid * value);
 			}
 
-			// Free swap graph
+			/* Free swap graph */
 			if (mem[1].total > 0) {
 				double value = 1.0 - ((double) mem[1].free / (double) mem[1].total);
 
-				//printf(".0f", val) only prints the integer part
+				/* printf(".0f", val) only prints the integer part */
 				if (display)
 					sock_printf(sock, "widget_set M swapgauge %i 4 %.0f\n",
-						lcd_wid - gauge_wid, lcd_cellwid * gauge_wid * value);
+						    lcd_wid - gauge_wid, lcd_cellwid * gauge_wid * value);
 			}
 		}
 	}
 	else {
-		char tmp[12];	// should be sufficient
+		char tmp[12];	/* should be sufficient */
 
-		// Total memory
+		/* Total memory */
 		sprintf_memory(tmp, mem[0].total * 1024.0, 1);
 		if (display)
 			sock_printf(sock, "widget_set M memtotl 3 1 {%6s}\n", tmp);
 
-		// Total swap
+		/* Total swap */
 		sprintf_memory(tmp, mem[1].total * 1024.0, 1);
 		if (display)
 			sock_printf(sock, "widget_set M swaptotl 3 2 {%6s}\n", tmp);
 
-		// Free memory graph
+		/* Free memory graph */
 		strcpy(tmp, "N/A");
 		if (mem[0].total > 0) {
 			double value = 1.0 - (double) (mem[0].free + mem[0].buffers + mem[0].cache)
 					 / (double) mem[0].total;
 
 			if (gauge_wid > 0) {
-				//printf(".0f", val) only prints the integer part
+				/* printf(".0f", val) only prints the integer part */
 				if (display)
 					sock_printf(sock, "widget_set M memgauge %i 1 %.0f\n",
 							gauge_offs, lcd_cellwid * gauge_wid * value);
@@ -198,13 +200,13 @@ mem_screen(int rep, int display, int *flags_ptr)
 		if (display)
 			sock_printf(sock, "widget_set M mem%% %i 1 {%5s}\n", lcd_wid - 5, tmp);
 
-		// Free swap graph
+		/* Free swap graph */
 		strcpy(tmp, "N/A");
 		if (mem[1].total > 0) {
 			double value = 1.0 - ((double) mem[1].free / (double) mem[1].total);
 
 			if (gauge_wid > 0) {
-				//printf(".0f", val) only prints the integer part
+				/* printf(".0f", val) only prints the integer part */
 				if (display)
 					sock_printf(sock, "widget_set M swapgauge %i 2 %.0f\n",
 						gauge_offs, lcd_cellwid * gauge_wid * value);
@@ -217,7 +219,7 @@ mem_screen(int rep, int display, int *flags_ptr)
 	}
 
 	return 0;
-}						 // End mem_screen()
+}
 
 
 /**
@@ -272,20 +274,22 @@ mem_top_screen(int rep, int display, int *flags_ptr)
 		sock_send_string(sock, "widget_add S title title\n");
 		sock_printf(sock, "widget_set S title {TOP MEM: %s}\n", get_hostname());
 
-		// frame from (2nd line, left) to (last line, right)
+		/* frame from (2nd line, left) to (last line, right) */
 		sock_send_string(sock, "widget_add S f frame\n");
-		sock_printf(sock, "widget_set S f 1 2 %i %i %i 5 v %i\n",
-				lcd_wid, lcd_hgt, lcd_wid,
-				// scroll rate: 1 line every X ticks (= 1/8 sec)
-				((lcd_hgt >= 4) ? 8 : 12));
 
-		// frame contents
+		/* scroll rate: 1 line every X ticks (= 1/8 sec) */
+		sock_printf(sock, "widget_set S f 1 2 %i %i %i 5 v %i\n",
+			    lcd_wid, lcd_hgt, lcd_wid,
+			    ((lcd_hgt >= 4) ? 8 : 12));
+
+		/* frame contents */
 		for (i = 1; i <= 5; i++) {
 			sock_printf(sock, "widget_add S %i string -in f\n", i);
 		}
 		sock_send_string(sock, "widget_set S 1 1 1 Checking...\n");
 	}
 
+	/* Create a new process list */
 	procs = LL_new();
 	if (procs == NULL) {
 		fprintf(stderr, "mem_top_screen: Error allocating list\n");
@@ -293,8 +297,12 @@ mem_top_screen(int rep, int display, int *flags_ptr)
 	}
 
 	machine_get_procs(procs);
+	/*
+	 * Ignore if machine_get_procs returns an errror. The list will be
+	 * empty then and all process info will be shown empty, too.
+	 */
 
-	// Now, print some info...
+	/* Now, print some info... */
 	LL_Rewind(procs);
 	LL_Sort(procs, sort_procs);
 	LL_Rewind(procs);
@@ -306,19 +314,16 @@ mem_top_screen(int rep, int display, int *flags_ptr)
 
 			sprintf_memory(mem, (double) p->totl * 1024.0, 1);
 
-			//printf("Mem hog: %s: %s\n", p->name, mem);
 			if (display) {
 				if (p->number > 1)
 					sock_printf(sock, "widget_set S %i 1 %i {%i %5s %s(%i)}\n",
-							i, i, i, mem, p->name, p->number);
+						    i, i, i, mem, p->name, p->number);
 				else
 					sock_printf(sock, "widget_set S %i 1 %i {%i %5s %s}\n",
-							i, i, i, mem, p->name);
+						    i, i, i, mem, p->name);
 			}
 		}
 		else {
-			//printf("Mem hog: none?\n");
-			//sprintf(buffer, "widget_set S %i 1 %i {}\n", i, i);
 			if (display)
 				sock_printf(sock, "widget_set S %i 1 %i { }\n", i, i);
 		}
@@ -326,12 +331,11 @@ mem_top_screen(int rep, int display, int *flags_ptr)
 		LL_Next(procs);
 	}
 
-	// Now clean it all up...
+	/* Delete the process list */
 	LL_Rewind(procs);
 	do {
 		procinfo_type *p = (procinfo_type *) LL_Get(procs);
 		if (p != NULL) {
-			//printf("Proc: %6ik %s\n", p->size, p->name);
 			free(p);
 		}
 	} while (LL_Next(procs) == 0);
