@@ -4,7 +4,8 @@
 extern char *address;
 extern int port;
 
-int connect_and_setup(void);
+int setup_connection(void);
+int teardown_connection(void);
 int read_response(char *str, int maxsize);
 int process_response(char *str);
 int update_display(void);
