@@ -46,7 +46,7 @@
 #include "lcd.h"
 #include "CFontzPacket.h"
 #include "CFontz633io.h"
-#include "report.h"
+#include "shared/report.h"
 #include "lcd_lib.h"
 #include "CFontz-charmap.h"
 #include "adv_bignum.h"
