@@ -44,7 +44,7 @@
 #include "lcd.h"
 #include "hd44780-charmap.h"
 #include "IOWarrior.h"
-#include "report.h"
+#include "shared/report.h"
 #include "lcd_lib.h"
 #include "adv_bignum.h"
 
