@@ -17,14 +17,18 @@ MODULE_EXPORT void debug_vbar (Driver *drvthis, int x, int y, int len, int promi
 MODULE_EXPORT void debug_hbar (Driver *drvthis, int x, int y, int len, int promille, int options);
 MODULE_EXPORT void debug_num (Driver *drvthis, int x, int num);
 MODULE_EXPORT int  debug_icon (Driver *drvthis, int x, int y, int icon);
-
+MODULE_EXPORT void debug_cursor(Driver *drvthis, int x, int y, int type);
 MODULE_EXPORT void debug_set_char (Driver *drvthis, int n, char *dat);
+MODULE_EXPORT int  debug_get_free_chars(Driver *drvthis);
+/* debug_heartbeat not implemented, use server's default */
 
 MODULE_EXPORT int  debug_get_contrast (Driver *drvthis);
 MODULE_EXPORT void debug_set_contrast (Driver *drvthis, int promille);
 MODULE_EXPORT int  debug_get_brightness (Driver *drvthis, int state);
 MODULE_EXPORT void debug_set_brightness (Driver *drvthis, int state, int promille);
 MODULE_EXPORT void debug_backlight (Driver *drvthis, int promille);
+MODULE_EXPORT void debug_output(Driver *drvthis, int value);
+
 MODULE_EXPORT const char *debug_get_info (Driver *drvthis);
 
 #endif
