@@ -31,7 +31,7 @@
 #endif
 
 #include "lcd.h"
-#include "report.h"
+#include "shared/report.h"
 
 #include "glcdlib.h"
 
