@@ -48,7 +48,7 @@
 
 #include "hd44780-ftdi.h"
 #include "hd44780-low.h"
-#include "report.h"
+#include "shared/report.h"
 
 /* connection type specific functions to be exposed using pointers in init() */
 void ftdi_HD44780_senddata(PrivateData *p, unsigned char displayID, unsigned char flags, unsigned char ch);
