@@ -74,7 +74,7 @@
 #include "hd44780-i2c.h"
 #include "hd44780-low.h"
 
-#include "report.h"
+#include "shared/report.h"
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
@@ -167,11 +167,6 @@ hd_init_i2c(Driver *drvthis)
 	report(RPT_INFO, "HD44780: I2C: Pin D7 mapped to 0x%02X", p->i2c_line_D7);
 	report(RPT_INFO, "HD44780: I2C: Invert Backlight %d", p->i2c_backlight_invert);
 	
-#ifdef HAVE_DEV_IICBUS_IIC_H
-	struct iiccmd cmd;
-	bzero(&cmd, sizeof(cmd));
-#endif
-
 	p->backlight_bit = p->i2c_line_BL;
 
 	/* READ CONFIG FILE */
