@@ -56,7 +56,7 @@
 
 #include "hd44780-rpi.h"
 #include "hd44780-low.h"
-#include "report.h"
+#include "shared/report.h"
 
 void lcdrpi_HD44780_senddata(PrivateData *p, unsigned char displayID, unsigned char flags, unsigned char ch);
 void lcdrpi_HD44780_backlight(PrivateData *p, unsigned char state);
@@ -154,6 +154,7 @@ check_board_rev(Driver *drvthis)
 		return NULL;
 	}
 
+	hw[0] = '\0';	/* initialize hw as empty string */
 	while (!feof(fp)) {
 		fgets(buf, sizeof(buf), fp);
 		sscanf(buf, "Hardware	: %7s", hw);
@@ -163,7 +164,10 @@ check_board_rev(Driver *drvthis)
 	fclose(fp);
 
 	/* On boards that have been overvolted, the MSB will be set */
-	if ((strcmp(hw, "BCM2708") != 0 && strcmp(hw, "BCM2709") != 0) || rev & 0xFFFFFF == 0) {
+	if ((strcmp(hw, "BCM2708") != 0 &&
+	     strcmp(hw, "BCM2709") != 0 &&
+	     strcmp(hw, "BCM2835") != 0) ||
+	    rev & 0xFFFFFF == 0) {
 		report(RPT_ERR, "check_board_rev: This board is not recognized as a Raspberry Pi!");
 		return NULL;
 	}
