@@ -50,18 +50,6 @@
  *		  2007 Peter Marschall <peter@adpm.de>
  */
 
-
-/*
- * Uncomment one of the lines below to select your desired delay generation
- * mechanism. Using DELAY_NANOSLEEP  seems to provide the best performance.
- *
- * Setting this here, overrides the set or selected algorithm in timing.h.
- * FIXME: Is this on purpose?
- */
-//#define DELAY_GETTIMEOFDAY
-#define DELAY_NANOSLEEP
-//#define DELAY_IOCALLS
-
 /* Default parallel port address */
 #define LPTPORT	 0x378
 
@@ -84,7 +72,7 @@
 #include "lcd.h"
 #include "lcd_lib.h"
 #include "hd44780.h"
-#include "report.h"
+#include "shared/report.h"
 #include "adv_bignum.h"
 
 #include "timing.h"
@@ -325,7 +313,7 @@ HD44780_init(Driver *drvthis)
 				/* Was a key specified in the config file ? */
 				if (s) {
 					p->keyMapMatrix[y][x] = strdup(s);
-					report(RPT_INFO, "HD44780: Matrix key %d %d: \"%s\"", x, y, s);
+					report(RPT_INFO, "HD44780: Matrix key %d %d: \"%s\"", x+1, y+1, s);
 				}
 			}
 		}
