@@ -41,12 +41,11 @@
 #include <errno.h>
 #include <pthread.h>
 
-#include <usb.h>
 #include <ftdi.h>
 
 #include "lcd.h"
 #include "lis.h"
-#include "report.h"
+#include "shared/report.h"
 #include "lcd_lib.h"
 #include "adv_bignum.h"
 #include "timing.h"
