@@ -32,14 +32,13 @@
 # include "config.h"
 #endif
 
+#include "widget.h"
+#include "screen.h"
 #include "menuitem.h"
 #include "menu.h"
 #include "shared/report.h"
 #include "drivers.h"
 
-#include "screen.h"
-#include "widget.h"
-
 
 extern Menu *custom_main_menu;
 
@@ -76,7 +75,7 @@ menu_get_subitem(Menu *menu, int index)
  * Search a menu for an entry by its ID, ignoring hidden entries.
  * \param menu     Pointer to menu to search in.
  * \param item_id  ID to search for.
- * \return  Index of subitem if found, and -1 otherwise.r
+ * \return  Index of subitem if found, and -1 otherwise.
  */
 static int
 menu_get_index_of(Menu *menu, char *item_id)
@@ -209,7 +208,7 @@ menu_create(char *id, MenuEventFunc(*event_func),
 	if (new_menu != NULL) {
 		new_menu->data.menu.contents = LL_new();
 		new_menu->data.menu.association = NULL;
-	}	
+	}
 
 	return new_menu;
 }
@@ -735,18 +734,20 @@ MenuResult menu_process_input(Menu *menu, MenuToken token, const char *key, unsi
 			break;
 		switch (subitem->type) {
 		  case MENUITEM_CHECKBOX:
-			/* Note: this works as CheckboxValue is an enum >= 0. */
-			subitem->data.checkbox.value--;
-			subitem->data.checkbox.value %= (subitem->data.checkbox.allow_gray) ? 3 : 2;
+			if (subitem->data.checkbox.value == 0)
+				subitem->data.checkbox.value = (subitem->data.checkbox.allow_gray) ? 2 : 1;
+			else
+				subitem->data.checkbox.value--;
 
 			if (subitem->event_func)
 				subitem->event_func(subitem, MENUEVENT_UPDATE);
 			return MENURESULT_NONE;
 		  case MENUITEM_RING:
 			/* ring: jump to the end if beginning is reached */
-			/* Note: this works as data.ring.value is a short >= 0 */
-			subitem->data.ring.value--;
-			subitem->data.ring.value %= LL_Length(subitem->data.ring.strings);
+			if (subitem->data.ring.value == 0)
+				subitem->data.ring.value = LL_Length(subitem->data.ring.strings) - 1;
+			else
+				subitem->data.ring.value--;
 
 			if (subitem->event_func)
 				subitem->event_func(subitem, MENUEVENT_UPDATE);
