@@ -11,7 +11,7 @@
  *
  * The slider, numeric & string input and menu have their own screen,
  * that comes to front when the items are selected.
- * One menuitem is in a different file: Menu data is in menu,h.
+ * One menuitem is in a different file: Menu data is in menu.h.
  */
 
 /* This file is part of LCDd, the lcdproc server.
@@ -27,13 +27,17 @@
 #ifndef MENUITEM_H
 #define MENUITEM_H
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+#ifdef HAVE_STDBOOL_H
+# include <stdbool.h>
+#endif
+#include "shared/defines.h"
+
 #include "shared/LL.h"
 
-#ifndef bool
-# define bool short
-# define true 1
-# define false 0
-#endif
+extern bool menu_permissive_goto; /* Flag from the configuration file */
 
 /*********************************************************************
  * Data definitions of the menustuff
@@ -41,6 +45,7 @@
 
 /** These values are used in the function tables in menuitem.c ! */
 typedef enum MenuItemType {
+	MENUITEM_INVALID  = -1,
 	MENUITEM_MENU     = 0,
 	MENUITEM_ACTION   = 1,
 	MENUITEM_CHECKBOX = 2,
@@ -85,6 +90,7 @@ typedef enum MenuResult {
 
 /** Events caused by a menuitem */
 typedef enum MenuEventType {
+	MENUEVENT_INVALID = -1,	/**< Special value for error handling */
 	MENUEVENT_SELECT = 0,	/**< Item has been selected
 				 * (action chosen) */
 	MENUEVENT_UPDATE = 1,	/**< Item has been modified
@@ -191,8 +197,6 @@ typedef struct MenuItem {
 } MenuItem;
 
 
-#include "screen.h"
-
 /*********************************************************************
  * Functions to use the menustuff
  */
